@@ -57,18 +57,24 @@ def header():
                 hg.C("object"),
                 hg.BaseElement(
                     hg.SPAN(hg.C("object")),
-                    hg.SPAN(
-                        hg.If(
-                            hg.C("request").resolver_match.url_name.endswith(".read"),
-                            editbutton,
-                            readbutton,
+                    hg.If(
+                        hg.C(f"request.GET.{settings.HIDEMENUS_URLPARAMETER}"),
+                        None,
+                        hg.SPAN(
+                            hg.If(
+                                hg.C("request").resolver_match.url_name.endswith(
+                                    ".read"
+                                ),
+                                editbutton,
+                                readbutton,
+                            ),
+                            copybutton,
+                            breadlayout.button.PrintPageButton(buttontype="ghost"),
+                            deletebutton,
+                            _class="no-print",
+                            style="margin-bottom: 1rem; margin-left: 1rem",
+                            width=3,
                         ),
-                        copybutton,
-                        breadlayout.button.PrintPageButton(buttontype="ghost"),
-                        deletebutton,
-                        _class="no-print",
-                        style="margin-bottom: 1rem; margin-left: 1rem",
-                        width=3,
                     ),
                 ),
                 hg.SPAN(hg.format(_("Add {}"), hg.C("view").model._meta.verbose_name)),
@@ -195,8 +201,9 @@ class BreadView:
     layout: typing.Optional[hg.BaseElement] = None
     _layout_cached: typing.Optional[hg.BaseElement] = None
     ajax_urlparameter = settings.AJAX_URLPARAMETER
+    hidemenus_urlparameter = settings.HIDEMENUS_URLPARAMETER
     page_layout: typing.Optional[
-        typing.Callable[[menu.Menu, hg.BaseElement], hg.BaseElement]
+        typing.Callable[[menu.Menu, hg.BaseElement, bool], hg.BaseElement]
     ] = None
     urlparams: typing.Iterable[typing.Tuple[str, typing.Type]] = ()
 
@@ -210,9 +217,13 @@ class BreadView:
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+
         self.ajax_urlparameter = kwargs.get(
             "ajax_urlparameter", getattr(self, "ajax_urlparameter")
         )
+        self.hidemenus_urlparameter = kwargs.get(
+            "hidemenus_urlparameter", getattr(self, "hidemenus_urlparameter")
+        )
 
         self.page_layout = (
             kwargs.get("page_layout", getattr(self, "page_layout"))
@@ -232,7 +243,11 @@ class BreadView:
         response_kwargs.setdefault("content_type", self.content_type)
         ret = self._get_layout_cached()
         if self.ajax_urlparameter not in self.request.GET:
-            ret = self.page_layout(menu.main, ret)
+            ret = self.page_layout(
+                menu.main,
+                ret,
+                hidemenus=self.hidemenus_urlparameter in self.request.GET,
+            )
 
         return breadlayout.render(self.request, ret, context, **response_kwargs)
 
